docs.rs failed to build marius-render-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
marius-render
Artifact writing and Axum integration for the Marius engine.
Status
Early development — API unstable.
License
MIT OR Apache-2.0